@@ -81,80 +81,82 @@ def telegram_eval_kommazahl(update: Update, context: CallbackContext, echter_wer
     match = re.search(
         KOMMAZAHL_PATTERN, update.message.text)
 
-    if match.group('vorkomma'):
-        schaetzung = int(match.group('vorkomma'))
-    else:
-        schaetzung = 0
+    if match:
+        if match.group('vorkomma'):
+            schaetzung = int(match.group('vorkomma'))
+        else:
+            schaetzung = 0
 
-    if match.group('nachkomma'):
-        schaetzung += float("0."+match.group('nachkomma'))
+        if match.group('nachkomma'):
+            schaetzung += float("0."+match.group('nachkomma'))
 
-    if schaetzung == echter_wert:
-        update.message.reply_text(richtig_text,
-                                  reply_markup=ReplyKeyboardRemove())
-    
-    differenz = schaetzung - echter_wert
-    if differenz == -1:
-        update.message.reply_text(spaeter_singular_text,
-                                  reply_markup=ReplyKeyboardRemove())
-    elif differenz < -1:
-        update.message.reply_text(spaeter_plural_text.format(abs(differenz)),
-                                  reply_markup=ReplyKeyboardRemove())
-    elif differenz == 1:
-        update.message.reply_text(vorher_singular_text,
-                                  reply_markup=ReplyKeyboardRemove())
-    elif differenz > 1:
-        update.message.reply_text(vorher_plural_text.format(abs(differenz)),
-                                  reply_markup=ReplyKeyboardRemove())
+        if schaetzung == echter_wert:
+            update.message.reply_text(richtig_text,
+                                    reply_markup=ReplyKeyboardRemove())
+        
+        differenz = schaetzung - echter_wert
+        if differenz == -1:
+            update.message.reply_text(spaeter_singular_text,
+                                    reply_markup=ReplyKeyboardRemove())
+        elif differenz < -1:
+            update.message.reply_text(spaeter_plural_text.format(abs(differenz)),
+                                    reply_markup=ReplyKeyboardRemove())
+        elif differenz == 1:
+            update.message.reply_text(vorher_singular_text,
+                                    reply_markup=ReplyKeyboardRemove())
+        elif differenz > 1:
+            update.message.reply_text(vorher_plural_text.format(abs(differenz)),
+                                    reply_markup=ReplyKeyboardRemove())
 
 def whatsapp_eval_kommazahl(client, update: WhatsAppUpdate, context, echter_wert, richtig_text, vorher_singular_text, vorher_plural_text, spaeter_singular_text, spaeter_plural_text):
     echter_wert = float(echter_wert)
     match = re.search(
         KOMMAZAHL_PATTERN, update.Body)
 
-    if match.group('vorkomma'):
-        schaetzung = int(match.group('vorkomma'))
-    else:
-        schaetzung = 0
+    if match:
+        if match.group('vorkomma'):
+            schaetzung = int(match.group('vorkomma'))
+        else:
+            schaetzung = 0
 
-    if match.group('nachkomma'):
-        schaetzung += float("0."+match.group('nachkomma'))
+        if match.group('nachkomma'):
+            schaetzung += float("0."+match.group('nachkomma'))
 
-    if schaetzung == echter_wert:
-        client.messages.create(
-            body=richtig_text,
-            from_=update.To,
-            to=update.From
-        )
+        if schaetzung == echter_wert:
+            client.messages.create(
+                body=richtig_text,
+                from_=update.To,
+                to=update.From
+            )
 
-    differenz = schaetzung - echter_wert
-    if differenz == -1:
-        client.messages.create(
-            body=spaeter_singular_text,
-            from_=update.To,
-            to=update.From
-        )
+        differenz = schaetzung - echter_wert
+        if differenz == -1:
+            client.messages.create(
+                body=spaeter_singular_text,
+                from_=update.To,
+                to=update.From
+            )
 
-    elif differenz < -1 or (-1 < differenz < 0):
-        client.messages.create(
-            body=spaeter_plural_text.format(abs(differenz)),
-            from_=update.To,
-            to=update.From
-        )
+        elif differenz < -1 or (-1 < differenz < 0):
+            client.messages.create(
+                body=spaeter_plural_text.format(abs(differenz)),
+                from_=update.To,
+                to=update.From
+            )
 
-    elif differenz == 1:
-        client.messages.create(
-            body=vorher_singular_text,
-            from_=update.To,
-            to=update.From
-        )
+        elif differenz == 1:
+            client.messages.create(
+                body=vorher_singular_text,
+                from_=update.To,
+                to=update.From
+            )
 
-    elif differenz > 1 or (0 < differenz < 1):
-        client.messages.create(
-            body=vorher_plural_text.format(abs(differenz)),
-            from_=update.To,
-            to=update.From
-        )
+        elif differenz > 1 or (0 < differenz < 1):
+            client.messages.create(
+                body=vorher_plural_text.format(abs(differenz)),
+                from_=update.To,
+                to=update.From
+            )
 
 def telegram_eval_laenge(update: Update, context: CallbackContext, echter_wert, richtig_text, vorher_singular_text, vorher_plural_text, spaeter_singular_text, spaeter_plural_text):
     warnings.warn("telegram_eval_laenge is deprecated", DeprecationWarning)
